/*
 * Part of Intel(R) Manageability Engine Interface Linux driver
 *
 * Copyright (c) 2003 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Copyright (c) 2009 Andriy Gapon
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *
 */

#ifndef HECI_REG_H
#define HECI_REG_H


#define    HECI_DEV_ID_82946GZ    0x29748086  /* 82946GZ/GL */
#define    HECI_DEV_ID_82G35      0x29848086  /* 82G35 Express */
#define    HECI_DEV_ID_82Q965     0x29948086  /* 82Q963/Q965 */
#define    HECI_DEV_ID_82G965     0x29A48086  /* 82P965/G965 */
#define    HECI_DEV_ID_82GM965    0x2A048086  /* Mobile PM965/GM965 */
#define    HECI_DEV_ID_82GME965   0x2A148086  /* Mobile GME965/GLE960 */
#define    HECI_DEV_ID_ICH9_82Q35 0x29B48086  /* 82Q35 Express */
#define    HECI_DEV_ID_ICH9_82G33 0x29C48086  /* 82G33/G31/P35/P31 Express */
#define    HECI_DEV_ID_ICH9_82Q33 0x29D48086  /* 82Q33 Express */
#define    HECI_DEV_ID_ICH9_82X38 0x29E48086  /* 82X38/X48 Express */
#define    HECI_DEV_ID_ICH9_3200  0x29F48086  /* 3200/3210 Server */
#define    HECI_DEV_ID_ICH9_6     0x28B48086  /* Bearlake */
#define    HECI_DEV_ID_ICH9_7     0x28C48086  /* Bearlake */
#define    HECI_DEV_ID_ICH9_8     0x28D48086  /* Bearlake */
#define    HECI_DEV_ID_ICH9_9     0x28E48086  /* Bearlake */
#define    HECI_DEV_ID_ICH9_10    0x28F48086  /* Bearlake */
#define    HECI_DEV_ID_ICH9M_1    0x2A448086  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_2    0x2A548086  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_3    0x2A648086  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_4    0x2A748086  /* Cantiga */
#define    HECI_DEV_ID_ICH10_1    0x2E048086  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_2    0x2E148086  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_3    0x2E248086  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_4    0x2E348086  /* Eaglelake */

/*
 * HECI HW Section
 */

/* HECI PCI BAR for memory mapped registers */
#define HECI_MBAR	PCIR_BAR(0)

/* HECI registers */
/* Documented in Intel(r) 4 Series Chipset Family Datasheet
 * www.intel.com/assets/pdf/datasheet/319970.pdf
 * section 10.3
 */

/* H_CB_WW - Host Circular Buffer (Write Window register (write only) */
#define H_CB_WW    0
/* H_CSR - Host Control Status register */
#define H_CSR      4
/* ME_CB_RW - ME Circular Buffer Read Window register (read only) */
#define ME_CB_RW   8
/* ME_CSR_HA - ME Control Status Host Access register (read only) */
#define ME_CSR_HA  0xC


/* Register bits of H_CSR (Host Control Status register) */

/* Host Circular Buffer Depth - maximum number of 32-bit entries in CB (read only) */
/* Note: This field is implemented with a "1-hot" scheme.
 * Only one bit will be set to a 1 at a time.
 */
/* H_CBD, H_CBWP and H_CBRP determine how much data
 * can be written by host into CB.
 */
#define H_CBD             0xFF000000

/* Host Circular Buffer Write Pointer (read only)*/
#define H_CBWP            0x00FF0000

/* Host Circular Buffer Read Pointer (read only) */
#define H_CBRP            0x0000FF00

/* Host Reset (r/w) */
/* Setting this bit to 1 clears H_RDY and ME_RDY bits */
#define H_RST             0x00000010

/* Host Ready */
#define H_RDY             0x00000008

/* Host Interrupt Generate */
/* After writing a message to CB, set this bit to generate interrupt to firmware,
 * subject to  ME_IE.
 */
#define H_IG              0x00000004

/* Host Interrupt Status */
/* This bit is set when firmware generates an interrupt to host,
 * it can be cleared by writing 1.
 */
#define H_IS              0x00000002

/* Host Interrupt Enable */
/* Enable firmware to send interrupts to host. */
#define H_IE              0x00000001


/* Register bits of ME_CSR_HA (ME Control Status Host Access register) */

/* ME CB (Circular Buffer) Depth HRA (Host Read Access)
 *  - host read only access to ME_CBD */
/* ME_CBD_HRA, ME_CBWP_HRA and ME_CBRP_HRA determine how much data
 * is available for reading from firmware in CB.
 */
#define ME_CBD_HRA        H_CBD

/* ME CB Write Pointer HRA - host read only access to ME_CBWP */
#define ME_CBWP_HRA       H_CBWP

/* ME CB Read Pointer HRA - host read only access to ME_CBRP */
#define ME_CBRP_HRA       H_CBRP

/* ME Reset HRA - host read only access to ME_RST */
#define ME_RST_HRA        0x00000010

/* ME Ready HRA - host read only access to ME_RDY */
/* If this bit is zero then communication with firmware is not possible. */
#define ME_RDY_HRA        0x00000008

/* ME Interrupt Generate HRA - host read only access to ME_IG */
#define ME_IG_HRA         0x00000004

/* ME Interrupt Status HRA - host read only access to ME_IS */
#define ME_IS_HRA         0x00000002

/* ME Interrupt Enable HRA - host read only access to ME_IE */
#define ME_IE_HRA         0x00000001


#endif /* HECI_REG_H */
